You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2021/02/22 09:19:53 UTC

[isis] 02/05: ISIS-2444: reworking projdoc tooling to split out into separate antora modules in a 'refguide' antora component

This is an automated email from the ASF dual-hosted git repository.

danhaywood pushed a commit to branch ISIS-2444
in repository https://gitbox.apache.org/repos/asf/isis.git

commit 994a1b6c6299f608eeba2bd87d6621d547d405ff
Author: danhaywood <da...@haywood-associates.co.uk>
AuthorDate: Mon Feb 22 07:05:55 2021 +0000

    ISIS-2444: reworking projdoc tooling to split out into separate antora modules in a 'refguide' antora component
---
 .../org/apache/isis/tooling/cli/projdoc/ProjectDocWriter.java     | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/tooling/cli/src/main/java/org/apache/isis/tooling/cli/projdoc/ProjectDocWriter.java b/tooling/cli/src/main/java/org/apache/isis/tooling/cli/projdoc/ProjectDocWriter.java
index 7cb3bb4..9be58c0 100644
--- a/tooling/cli/src/main/java/org/apache/isis/tooling/cli/projdoc/ProjectDocWriter.java
+++ b/tooling/cli/src/main/java/org/apache/isis/tooling/cli/projdoc/ProjectDocWriter.java
@@ -127,8 +127,7 @@ final class ProjectDocWriter {
             final @NonNull CliConfig.Commands.Index index
             ) {
 
-        // eg: was: antora/components/system/modules/generated
-        // eg: now: antora/components/refguide
+        // eg: antora/components/refguide
         final File outputRootFolder = global.getOutputRootFolder();
         val indexFolder = index.getDocumentIndexFolder(outputRootFolder);
 
@@ -140,14 +139,17 @@ final class ProjectDocWriter {
         .skip(global.getNamespacePartsSkipCount())
         .peek(subDir-> {
             // applib
             // ... so updates to antora/components/refguide/modules/applib
             destFolderBuilder.update(currentDir -> new File(currentDir, "modules"));
             destFolderBuilder.update(currentDir -> new File(currentDir, subDir));
+            destFolderBuilder.update(currentDir -> new File(currentDir, "pages"));
+            destFolderBuilder.update(currentDir -> new File(currentDir, "index"));
         })
         // annotation
         .skip(1)
         .forEach(subDir-> {
             // annotation
+            // ... so updates to antora/components/refguide/modules/applib/pages/index/annotation
             destFolderBuilder.update(currentDir -> new File(currentDir, subDir));
         });
@@ -140,14 +139,17 @@ final class ProjectDocWriter {
         .peek(subDir-> {
             // applib
-            // ... so updates to antora/components/refguide/modules/applib
+            // ... so updates to antora/components/refguide/modules/applib/pages/index
             destFolderBuilder.update(currentDir -> new File(currentDir, "modules"));
             destFolderBuilder.update(currentDir -> new File(currentDir, subDir));